pub fn apply_dupname_fixups(root: &mut Node, fixups: &[DupnameFixup])Expand description
Post-parse pass: move name from names to dupnames on the node
carrying node_id (the FIRST occurrence keeps its id, loses its name).
pub fn apply_dupname_fixups(root: &mut Node, fixups: &[DupnameFixup])Post-parse pass: move name from names to dupnames on the node
carrying node_id (the FIRST occurrence keeps its id, loses its name).