pub struct DupnameFixup {
pub name: String,
pub node_id: String,
}Expand description
A deferred “first node loses its name too” fixup: on a duplicate name,
docutils dupnames BOTH nodes, but the first one is already deep in the
tree — the parser applies these after parsing via
apply_dupname_fixups.
Fields
name: Stringnode_id: StringTrait Implementations
Sourceimpl Clone for DupnameFixup
impl Clone for DupnameFixup
Sourcefn clone(&self) -> DupnameFixup
fn clone(&self) -> DupnameFixup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DupnameFixup
impl Debug for DupnameFixup
Sourceimpl PartialEq for DupnameFixup
impl PartialEq for DupnameFixup
Sourcefn eq(&self, other: &DupnameFixup) -> bool
fn eq(&self, other: &DupnameFixup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DupnameFixup
impl StructuralPartialEq for DupnameFixup